==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, _super);
    function WebBaseToolbarColumnActionsDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b = function (a) {
        if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        if (a.j(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.y(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c = function (a) {
        WebGridToolbarBaseActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("Name", "String");
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.d = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
        a.aa("WebBaseToolbarColumnActionsDirective", function () { return new WebBaseToolbarColumnActionsDirectiveDescription(); });
        a.z("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
}(Base));
export { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarBaseActionDescriptionMetadata } from "./WebGridToolbarBaseActionDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, _super);
    function WebBaseToolbarColumnActionsDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b = function (a) {
        if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        if (a.k(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c = function (a) {
        WebGridToolbarBaseActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("Name", "String");
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.d = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
        a.ac("WebBaseToolbarColumnActionsDirective", function () { return new WebBaseToolbarColumnActionsDirectiveDescription(); });
        a.ab("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
}(Base));
export { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata };
